# coding: utf-8

"""
    CulebraTester

    ## Snaky Android Test --- If you want to be able to try out the API using the **Execute** or **TRY** button from this page - an android device should be connected using `adb` - the server should have been started using `./culebratester2 start-server`  then you will be able to invoke the API and see the responses.   # noqa: E501

    OpenAPI spec version: 2.0.39
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InlineResponse200(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'object': 'object',
        'oid': 'int'
    }

    attribute_map = {
        'object': 'object',
        'oid': 'oid'
    }

    def __init__(self, object=None, oid=None):  # noqa: E501
        """InlineResponse200 - a model defined in Swagger"""  # noqa: E501
        self._object = None
        self._oid = None
        self.discriminator = None
        if object is not None:
            self.object = object
        if oid is not None:
            self.oid = oid

    @property
    def object(self):
        """Gets the object of this InlineResponse200.  # noqa: E501


        :return: The object of this InlineResponse200.  # noqa: E501
        :rtype: object
        """
        return self._object

    @object.setter
    def object(self, object):
        """Sets the object of this InlineResponse200.


        :param object: The object of this InlineResponse200.  # noqa: E501
        :type: object
        """

        self._object = object

    @property
    def oid(self):
        """Gets the oid of this InlineResponse200.  # noqa: E501


        :return: The oid of this InlineResponse200.  # noqa: E501
        :rtype: int
        """
        return self._oid

    @oid.setter
    def oid(self, oid):
        """Sets the oid of this InlineResponse200.


        :param oid: The oid of this InlineResponse200.  # noqa: E501
        :type: int
        """

        self._oid = oid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CulebraTester

    ## Snaky Android Test --- If you want to be able to try out the API using the **Execute** or **TRY** button from this page - an android device should be connected using `adb` - the server should have been started using `./culebratester2 start-server`  then you will be able to invoke the API and see the responses.   # noqa: E501

    OpenAPI spec version: 2.0.39
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import culebratester_client
from culebratester_client.api.default_api import DefaultApi  # noqa: E501
from culebratester_client.rest import ApiException


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_configurator_get_wait_for_idle_timeout_get(self):
        """Test case for configurator_get_wait_for_idle_timeout_get

        Gets the current timeout used for waiting for the user interface to go into an idle state.  # noqa: E501
        """
        pass

    def test_configurator_set_wait_for_idle_timeout_get(self):
        """Test case for configurator_set_wait_for_idle_timeout_get

        Sets the timeout for waiting for the user interface to go into an idle state before starting a uiautomator action.  # noqa: E501
        """
        pass

    def test_culebra_help_api_get(self):
        """Test case for culebra_help_api_get

        Gets help  # noqa: E501
        """
        pass

    def test_culebra_info_get(self):
        """Test case for culebra_info_get

        Gets information about this app.  # noqa: E501
        """
        pass

    def test_device_display_real_size_get(self):
        """Test case for device_display_real_size_get

        Gets display real size.  # noqa: E501
        """
        pass

    def test_device_dumpsys_get(self):
        """Test case for device_dumpsys_get

        """
        pass

    def test_device_wait_for_new_toast_get(self):
        """Test case for device_wait_for_new_toast_get

        Waits for a new Toast.  # noqa: E501
        """
        pass

    def test_object_store_clear_get(self):
        """Test case for object_store_clear_get

        Clears all the objects in store.  # noqa: E501
        """
        pass

    def test_object_store_list_get(self):
        """Test case for object_store_list_get

        Lists the objects in store.  # noqa: E501
        """
        pass

    def test_object_store_remove_get(self):
        """Test case for object_store_remove_get

        Removes an object.  # noqa: E501
        """
        pass

    def test_target_context_start_activity_get(self):
        """Test case for target_context_start_activity_get

        Starts an Activity.  # noqa: E501
        """
        pass

    def test_ui_device_clear_last_traversed_text_get(self):
        """Test case for ui_device_clear_last_traversed_text_get

        Clears the text from the last UI traversal event.  # noqa: E501
        """
        pass

    def test_ui_device_click_get(self):
        """Test case for ui_device_click_get

        Clicks at the specified location.  # noqa: E501
        """
        pass

    def test_ui_device_click_post(self):
        """Test case for ui_device_click_post

        Clicks at the specified locations.  # noqa: E501
        """
        pass

    def test_ui_device_current_package_name_get(self):
        """Test case for ui_device_current_package_name_get

        Gets the current package name.  # noqa: E501
        """
        pass

    def test_ui_device_display_height_get(self):
        """Test case for ui_device_display_height_get

        Gets the display height.  # noqa: E501
        """
        pass

    def test_ui_device_display_rotation_get(self):
        """Test case for ui_device_display_rotation_get

        Gets the display rotation.  # noqa: E501
        """
        pass

    def test_ui_device_display_size_dp_get(self):
        """Test case for ui_device_display_size_dp_get

        Gets the display size in DP.  # noqa: E501
        """
        pass

    def test_ui_device_display_width_get(self):
        """Test case for ui_device_display_width_get

        Gets the display width.  # noqa: E501
        """
        pass

    def test_ui_device_drag_get(self):
        """Test case for ui_device_drag_get

        Performs a swipe from one coordinate to another coordinate.  # noqa: E501
        """
        pass

    def test_ui_device_dump_window_hierarchy_get(self):
        """Test case for ui_device_dump_window_hierarchy_get

        Dumps the window hierarchy.  # noqa: E501
        """
        pass

    def test_ui_device_find_object_get(self):
        """Test case for ui_device_find_object_get

        Finds an object.  # noqa: E501
        """
        pass

    def test_ui_device_find_object_post(self):
        """Test case for ui_device_find_object_post

        Finds an object.  # noqa: E501
        """
        pass

    def test_ui_device_find_objects_get(self):
        """Test case for ui_device_find_objects_get

        Finds *all* objects that match the selector criteria.  # noqa: E501
        """
        pass

    def test_ui_device_find_objects_post(self):
        """Test case for ui_device_find_objects_post

        Finds *all* objects.  # noqa: E501
        """
        pass

    def test_ui_device_freeze_rotation_get(self):
        """Test case for ui_device_freeze_rotation_get

        Disables the sensors and freezes the device rotation at its current rotation state.  # noqa: E501
        """
        pass

    def test_ui_device_has_object_get(self):
        """Test case for ui_device_has_object_get

        Returns whether there is a match for the given selector criteria.  # noqa: E501
        """
        pass

    def test_ui_device_is_natural_orientation_get(self):
        """Test case for ui_device_is_natural_orientation_get

        Check if the device is in its natural orientation.  # noqa: E501
        """
        pass

    def test_ui_device_is_screen_on_get(self):
        """Test case for ui_device_is_screen_on_get

        Checks the power manager if the screen is ON.  # noqa: E501
        """
        pass

    def test_ui_device_last_traversed_text_get(self):
        """Test case for ui_device_last_traversed_text_get

        Retrieves the text from the last UI traversal event received.  # noqa: E501
        """
        pass

    def test_ui_device_pixel_get(self):
        """Test case for ui_device_pixel_get

        Gets a pixel from device screen.  # noqa: E501
        """
        pass

    def test_ui_device_press_back_get(self):
        """Test case for ui_device_press_back_get

        Simulates a short press on the BACK button.  # noqa: E501
        """
        pass

    def test_ui_device_press_delete_get(self):
        """Test case for ui_device_press_delete_get

        Simulates a short press on the DELETE key.  # noqa: E501
        """
        pass

    def test_ui_device_press_enter_get(self):
        """Test case for ui_device_press_enter_get

        Simulates a short press on the ENTER key.  # noqa: E501
        """
        pass

    def test_ui_device_press_home_get(self):
        """Test case for ui_device_press_home_get

        Simulates a short press on the HOME button.  # noqa: E501
        """
        pass

    def test_ui_device_press_key_code_get(self):
        """Test case for ui_device_press_key_code_get

        Simulates a short press using a key code.  # noqa: E501
        """
        pass

    def test_ui_device_press_recent_apps_get(self):
        """Test case for ui_device_press_recent_apps_get

        Simulates a short press on the Recent Apps button.  # noqa: E501
        """
        pass

    def test_ui_device_product_name_get(self):
        """Test case for ui_device_product_name_get

        Retrieves the product name of the device.  # noqa: E501
        """
        pass

    def test_ui_device_screenshot_get(self):
        """Test case for ui_device_screenshot_get

        Gets the device screenshot.  # noqa: E501
        """
        pass

    def test_ui_device_swipe_get(self):
        """Test case for ui_device_swipe_get

        Performs a swipe.  # noqa: E501
        """
        pass

    def test_ui_device_swipe_post(self):
        """Test case for ui_device_swipe_post

        Performs a swipe between points in the Point array.  # noqa: E501
        """
        pass

    def test_ui_device_unfreeze_rotation_get(self):
        """Test case for ui_device_unfreeze_rotation_get

        Re-enables the sensors and un-freezes the device rotation allowing its contents to rotate with the device physical rotation  # noqa: E501
        """
        pass

    def test_ui_device_wait_for_idle_get(self):
        """Test case for ui_device_wait_for_idle_get

        Waits for the current application to idle.  # noqa: E501
        """
        pass

    def test_ui_device_wait_for_window_update_get(self):
        """Test case for ui_device_wait_for_window_update_get

        Waits for a window content update event to occur.  # noqa: E501
        """
        pass

    def test_ui_device_wait_get(self):
        """Test case for ui_device_wait_get

        Waits for given the condition to be met.  # noqa: E501
        """
        pass

    def test_ui_object2_oid_clear_get(self):
        """Test case for ui_object2_oid_clear_get

        Clears the text content if this object is an editable field.  # noqa: E501
        """
        pass

    def test_ui_object2_oid_click_and_wait_get(self):
        """Test case for ui_object2_oid_click_and_wait_get

        Clicks on the specified object.  # noqa: E501
        """
        pass

    def test_ui_object2_oid_click_get(self):
        """Test case for ui_object2_oid_click_get

        Clicks on the specified object.  # noqa: E501
        """
        pass

    def test_ui_object2_oid_dump_get(self):
        """Test case for ui_object2_oid_dump_get

        Dumps the specified object.  # noqa: E501
        """
        pass

    def test_ui_object2_oid_get_content_description_get(self):
        """Test case for ui_object2_oid_get_content_description_get

        Returns the content description for this object.  # noqa: E501
        """
        pass

    def test_ui_object2_oid_get_text_get(self):
        """Test case for ui_object2_oid_get_text_get

        Gets the text content.  # noqa: E501
        """
        pass

    def test_ui_object2_oid_long_click_get(self):
        """Test case for ui_object2_oid_long_click_get

        Long-clicks on the specified object.  # noqa: E501
        """
        pass

    def test_ui_object2_oid_set_text_get(self):
        """Test case for ui_object2_oid_set_text_get

        Sets the text content if this object is an editable field.  # noqa: E501
        """
        pass

    def test_ui_object2_oid_set_text_post(self):
        """Test case for ui_object2_oid_set_text_post

        Sets the text content if this object is an editable field.  # noqa: E501
        """
        pass

    def test_until_find_object_get(self):
        """Test case for until_find_object_get

        Returns a SearchCondition that is satisfied when at least one element matching the selector can be found.  # noqa: E501
        """
        pass

    def test_until_find_object_post(self):
        """Test case for until_find_object_post

        Returns a SearchCondition that is satisfied when at least one element matching the selector can be found.  # noqa: E501
        """
        pass

    def test_until_new_window_get(self):
        """Test case for until_new_window_get

        Returns a condition that depends on a new window having appeared.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
